#! /usr/bin/python

#
# Create an idx volume for a given section
#
# example usage: python createidx.py -d "2 2 2" -o /tmp/tst.idx -f "DAPI BEN VAS OXY" -t uint8
#

import sys
import argparse
import subprocess
 
def createidx(visusconvert,name,dims,dtype,fields,scale,origin):
    ndtype=1
    strdims=""
    box=""
    fieldstr=""
    for d in dims:
        strdims=strdims+" "+str(d)
        box=box+" 0 "+str(int(d)-1)
    for f in fields:
        fieldstr=fieldstr+" "+f+" "+str(ndtype)+"*"+dtype+" compressed + "
    args=["visusconvert",
          "--create",name,
          "--box",box,
          "--fields",fieldstr]

    # add scale and origin to idx (since visusconvert doesn't do this yet)
    #todo: read .idx, insert (scale) and (origin) fields.
     
    #print args
    proc=subprocess.Popen(args,executable=visusconvert)
    proc.wait()

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="create an idx volume")
    parser.add_argument("-v", "--visus", dest="visus", default="visusconvert",
                        help="path/to/visusconvert")
    parser.add_argument("-d", "--dims", dest="dims", required=True,
                        help="dimensions of the volume to create (ex: \"x y z u v\")")
    parser.add_argument("-n", "--name", dest="filename", default="/tmp/synth.idx",
                        help="name of idx file to create (ex: /processed/rb2_84/idx/0001.idx)")
    parser.add_argument("-f", "--fields", dest="fields", default="C01 C02 C03 C04",
                        help="names of the fields in this volume")
    parser.add_argument("-t", "--dtype", dest="dtype", default="uint8",
                        choices=["uint8","uint16","uint32","uint64","ufloat32","ufloat64","int8","int16","int32","int64","float32","float64"],
                        help="type to use for data")
    parser.add_argument("-s", "--scale", dest="scale", default="1.0 1.0 1.0",
                        help="scale of each dimension (ex: \"0.31 0.31 0.75\")")
    parser.add_argument("-o", "--origin", dest="origin", default="0.0 0.0 0.0",
                        help="xyz location of this volume in space (ex: \"-2301.3 0.0 3.74\")")
    args=parser.parse_args()

    createidx(args.visus,
              args.filename,
              args.dims.split(),
              args.dtype,
              args.fields.split(),
              args.scale,
              args.origin)

